@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#  -*- mode: python; indent-tabs-mode: nil; -*- coding: iso-8859-1 -*-
+#  -*- mode: python; indent-tabs-mode: nil; -*- coding: UTF8 -*-
 
 """
 EbookConverter.py
@@ -350,6 +350,9 @@ def run_job_queue(job_queue):
                 mod_timestamp = datetime.datetime.fromtimestamp(os.path.getmtime(filename))
                 if datetime.date.today() - mod_timestamp.date() > datetime.timedelta(1):
                     critical('Failed to build new file: %s', filename)
+                for ext in ['.gz', '.gzip']:
+                    if os.access(filename + ext, os.W_OK):
+                        os.remove(filename + ext)
             elif filename.split('.')[-1] not in {'facebook', 'twitter', 'picsdir'}:
                 critical('Failed to build file: %s', filename)
     else:
